
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.10.0',
    'branch_nick': '(detached',
    'revision_id': '605fa468a22f510883b3fa9b0911cc2e87bf97a8',
    'revno': 4769
}
